hdr.2d(x, y, prob = c(50, 95, 99), den=NULL, kde.package=c("ash","ks"), h=NULL,
xextend=0.15, yextend=0.15)
## S3 method for class 'hdr2d':
plot(x, shaded=TRUE, show.points=FALSE, outside.points=FALSE, pch=20,
shadecols=gray((length(x$alpha):1)/(length(x$alpha)+1)), pointcol=1, ...)
hdr.boxplot.2d(x, y, prob=c(50, 99), kde.package=c("ash","ks"), h=NULL,
xextend=0.15, yextend=0.15, xlab="", ylab="",
shadecols=gray((length(prob):1)/(length(prob)+1)), pointcol=1, ...)x.NULL, the density is estimated.den=NULL.x. The density is estimated on a grid extended by xextend beyond the range of x.y. The density is estimated on a grid extended by yextend beyond the range of y.TRUE, the HDR contours are shown as shaded regions.TRUE, the observations are plotted over the top of the HDR contours.TRUE, the observations lying outside the largest HDR are shown.ash2 or kde is used to
do the calculations. Then Hyndman's (1996) density quantile algorithm is used to compute the HDRs.
hdr.2d returns an object of class hdr2d containing all the information needed to compute the HDR contours. This object can be plotted using plot.hdr2d.
hdr.boxplot.2d produces a bivariate HDR boxplot. This is a special case of applying plot.hdr2d to an object computed using hdr.2d.hdr.boxplotx <- c(rnorm(200,0,1),rnorm(200,4,1))
y <- c(rnorm(200,0,1),rnorm(200,4,1))
hdr.boxplot.2d(x,y)
hdrinfo <- hdr.2d(x,y)
plot(hdrinfo, pointcol="red", show.points=TRUE, pch=3)Run the code above in your browser using DataLab